Okay, here is the table with explanations and examples for each universal strategy, tailored for a GUI Agent's reference.

**Universal Strategies with Explanations and Examples**

| universal strategy ID | universal strategy        | Explanation (for GUI Agent)                                                                                                                               | Example (similar to original strategy)                        |
| :-------------------- | :------------------------ | :-------------------------------------------------------------------------------------------------------------------------------------------------------- | :------------------------------------------------------------ |
| US1                   | Navigate To Page/Section  | Move to a specific page, view, or section within the application interface. This typically involves clicking links, menu items, or buttons that lead to a new screen or area. | Navigate to the Orders Report page.                           |
| US2                   | Search/Filter/Sort Data   | Use search boxes, filters (like dropdowns, checkboxes), or sorting controls to locate, narrow down, or reorder data displayed in a list, table, or results view. | Filter Issues by Label 'Bug'.                                 |
| US3                   | Configure Parameters/Settings | Set or adjust specific options, parameters, or settings, often within a form or configuration panel, before executing an action (like generating a report or creating an item). | Configure Date Range for the report from 2023-01-01 to 2023-01-31. |
| US4                   | Execute Action/Process    | Initiate a specific process or action by interacting with a primary action element, such as clicking a 'Submit', 'Generate', 'Calculate', 'Add', 'Follow', or 'Save' button. | Generate and Submit the Sales Report.                         |
| US5                   | View/Inspect Item Details | Open or focus on a specific item (e.g., an order, product, user profile, issue) to examine its detailed information, often by clicking on the item in a list or a dedicated 'View'/'Details' button. | View the Details of Order #12345.                             |
| US6                   | Extract/Retrieve Information | Read and capture specific pieces of information (like text, numbers, status) displayed on the current page or within an item's details.                 | Retrieve the Purchase Date from the Order Details section.    |
| US7                   | Analyze/Evaluate/Verify Data | Perform cognitive tasks on the displayed data, such as comparing values, checking conditions, interpreting content, identifying patterns, or making judgments based on the information. | Analyze Review Content to identify mentions of 'poor quality'. |
| US8                   | Navigate Within Data/Results | Move through multiple pages or sections of data or search results, typically using pagination controls (e.g., 'Next', 'Previous', page numbers) or scrolling. | Navigate Through Search Result Pages using the 'Next' button. |
| US9                   | Create Item               | Complete the process of adding a new entity (e.g., post, project, issue, user, rule) to the system, typically by filling out a form and submitting it.      | Create New Project named 'My Research Project'.               |
| US10                  | Update/Modify Item        | Change or edit attributes or content of an existing item (e.g., update profile information, modify an order, edit a post, change product status).        | Update User Profile Homepage URL to 'https://new-website.com'. |
| US11                  | Delete Item               | Remove an existing item (e.g., a review, product, post) from the system, often involving a selection step and a confirmation.                            | Delete the selected Pending Review.                           |

---

**Mapping Table (Re-presented for completeness as requested)**

| task id (number) | original strategy                                               | universal strategy                | universal strategy ID |
| :--------------- | :-------------------------------------------------------------- | :-------------------------------- | :-------------------- |
| 103              | Navigate to the Repository                                      | Navigate To Page/Section          | US1                   |
| 103              | Filter Issues by Label                                          | Search/Filter/Sort Data           | US2                   |
| 109              | Navigate to Orders Report                                       | Navigate To Page/Section          | US1                   |
| 109              | Configure Report Parameters                                     | Configure Parameters/Settings     | US3                   |
| 109              | Generate and Organize Report                                    | Execute Action/Process            | US4                   |
| 115              | Navigate to Product Reviews Report                              | Navigate To Page/Section          | US1                   |
| 115              | Search for 'chloe tank' Product Reviews                         | Search/Filter/Sort Data           | US2                   |
| 117              | Access the Order History to Locate the Earliest Order           | Navigate To Page/Section          | US1                   |
| 117              | Identify and View the Earliest Order's Details                  | View/Inspect Item Details         | US5                   |
| 117              | Retrieve the Purchase Date from Order Details                   | Extract/Retrieve Information      | US6                   |
| 123              | Navigate to Product Reviews Report                              | Navigate To Page/Section          | US1                   |
| 123              | Analyze Product Reviews Data                                    | Analyze/Evaluate/Verify Data      | US7                   |
| 123              | Access and Review Customer Feedback                             | View/Inspect Item Details         | US5                   |
| 125              | Search for Teeth Grinding Mouth Guards                          | Search/Filter/Sort Data           | US2                   |
| 125              | Sort Results by Price                                           | Search/Filter/Sort Data           | US2                   |
| 125              | Navigate Through Pages to Determine Price Range                 | Navigate Within Data/Results      | US8                   |
| 127              | Navigate to the Search Terms Report                             | Navigate To Page/Section          | US1                   |
| 127              | Sort and Analyze Search Term Data                               | Analyze/Evaluate/Verify Data      | US7                   |
| 131              | Navigate to the Orders Page                                     | Navigate To Page/Section          | US1                   |
| 131              | Prepare Order List for Analysis                                 | Search/Filter/Sort Data           | US2                   |
| 131              | Extract Item Count from Recent Orders                           | Extract/Retrieve Information      | US6                   |
| 131              | Return to Main Context                                          | Execute Action/Process            | US4                   |
| 139              | Locate Joe Biden's Hometown via Wikipedia                       | Navigate To Page/Section          | US1                   |
| 139              | Set Up Route Planning in OpenStreetMap                          | Configure Parameters/Settings     | US3                   |
| 139              | Retrieve Driving Time Estimate                                  | Extract/Retrieve Information      | US6                   |
| 149              | Access Account and Navigate to Order History                    | Navigate To Page/Section          | US1                   |
| 149              | Locate February 2023 Orders                                     | Search/Filter/Sort Data           | US2                   |
| 149              | Extract Product Color Information                               | Extract/Retrieve Information      | US6                   |
| 15               | Navigate to Product Reviews Report                              | Navigate To Page/Section          | US1                   |
| 15               | Filter Reviews Containing 'best'                                | Search/Filter/Sort Data           | US2                   |
| 15               | Retrieve Results                                                | Extract/Retrieve Information      | US6                   |
| 155              | Search for Starting Point                                       | Search/Filter/Sort Data           | US2                   |
| 155              | Initiate Directions from Starting Point                         | Execute Action/Process            | US4                   |
| 155              | Configure and Generate Route                                    | Execute Action/Process            | US4                   |
| 156              | Use Search to Filter Merge Requests                             | Search/Filter/Sort Data           | US2                   |
| 157              | Access the "All Customers" List                                 | Navigate To Page/Section          | US1                   |
| 162              | Search for Nintendo Switch Card Storage Solutions               | Search/Filter/Sort Data           | US2                   |
| 162              | Evaluate Product Options                                        | Analyze/Evaluate/Verify Data      | US7                   |
| 167              | Access Customer Reviews Section                                 | Navigate To Page/Section          | US1                   |
| 167              | Analyze Review Content                                          | Analyze/Evaluate/Verify Data      | US7                   |
| 167              | Verify Rating Context                                           | Analyze/Evaluate/Verify Data      | US7                   |
| 169              | Navigate to User's Contributions                                | Navigate To Page/Section          | US1                   |
| 169              | Identify High-Star Repositories                                 | Analyze/Evaluate/Verify Data      | US7                   |
| 173              | Navigate to Assigned Issues                                     | Navigate To Page/Section          | US1                   |
| 173              | Filter Issues by Keyword 'better'                               | Search/Filter/Sort Data           | US2                   |
| 173              | Sort Issues by Latest Update                                    | Search/Filter/Sort Data           | US2                   |
| 173              | Open and Verify Target Issue                                    | View/Inspect Item Details         | US5                   |
| 182              | Access the Issues List                                          | Navigate To Page/Section          | US1                   |
| 182              | Filter and Sort Issues                                          | Search/Filter/Sort Data           | US2                   |
| 182              | Open and Verify Target Issue                                    | View/Inspect Item Details         | US5                   |
| 184              | Navigate to the Products Section                                | Navigate To Page/Section          | US1                   |
| 184              | Apply Quantity Filter                                           | Search/Filter/Sort Data           | US2                   |
| 190              | Access Order History                                            | Navigate To Page/Section          | US1                   |
| 190              | Retrieve Latest Order Details                                   | View/Inspect Item Details         | US5                   |
| 196              | Navigate to Orders Report                                       | Navigate To Page/Section          | US1                   |
| 196              | Configure Date Range                                            | Configure Parameters/Settings     | US3                   |
| 196              | Analyze Completed Orders                                        | Analyze/Evaluate/Verify Data      | US7                   |
| 196              | Analyze Canceled Orders                                         | Analyze/Evaluate/Verify Data      | US7                   |
| 196              | Compare Payments                                                | Analyze/Evaluate/Verify Data      | US7                   |
| 202              | Navigate to Orders Report                                       | Navigate To Page/Section          | US1                   |
| 202              | Filter for Canceled Orders                                      | Search/Filter/Sort Data           | US2                   |
| 202              | Set Date Range to Capture Recent Orders                         | Configure Parameters/Settings     | US3                   |
| 202              | Generate and Analyze Report                                     | Execute Action/Process            | US4                   |
| 205              | Navigate to the Commits Section                                 | Navigate To Page/Section          | US1                   |
| 205              | Filter Commits by Author                                        | Search/Filter/Sort Data           | US2                   |
| 205              | Locate Commits on March 5, 2023                                 | Search/Filter/Sort Data           | US2                   |
| 215              | Identify Search-Related Issues                                  | Search/Filter/Sort Data           | US2                   |
| 215              | Analyze Product Configuration                                   | Analyze/Evaluate/Verify Data      | US7                   |
| 215              | Evaluate Customer Feedback                                      | Analyze/Evaluate/Verify Data      | US7                   |
| 220              | Locate Gardner Steel Conference Center                          | Navigate To Page/Section          | US1                   |
| 220              | Identify Nearby Hotels                                          | Search/Filter/Sort Data           | US2                   |
| 220              | Calculate Walking Routes                                        | Execute Action/Process            | US4                   |
| 221              | Locate CMU on OpenStreetMap                                     | Navigate To Page/Section          | US1                   |
| 221              | Find nearest USPS post office                                   | Search/Filter/Sort Data           | US2                   |
| 221              | Calculate travel times                                          | Execute Action/Process            | US4                   |
| 225              | Search for 'sephora brush' products                            | Search/Filter/Sort Data           | US2                   |
| 225              | Access product details                                          | View/Inspect Item Details         | US5                   |
| 227              | Search for EYZUTAK Products                                     | Search/Filter/Sort Data           | US2                   |
| 227              | Access Product Page                                             | Navigate To Page/Section          | US1                   |
| 227              | Explore Product Variants for Pricing                            | View/Inspect Item Details         | US5                   |
| 23               | Access Customer Reviews Section                                 | Navigate To Page/Section          | US1                   |
| 23               | Inspect Reviews for Fingerprint Resistance Mentions             | Analyze/Evaluate/Verify Data      | US7                   |
| 235              | Navigate to the My Orders Page                                  | Navigate To Page/Section          | US1                   |
| 235              | Identify the Most Recent Under-Delivery Order                   | Search/Filter/Sort Data           | US2                   |
| 236              | Locate Carnegie Mellon University on OpenStreetMap              | Navigate To Page/Section          | US1                   |
| 236              | Search for Pharmacies Near Carnegie Mellon University           | Search/Filter/Sort Data           | US2                   |
| 236              | Identify and Select the Nearest Pharmacy                        | Execute Action/Process            | US4                   |
| 240              | Search for Competitive Swimwear                                 | Search/Filter/Sort Data           | US2                   |
| 240              | Sort Results by Price                                           | Search/Filter/Sort Data           | US2                   |
| 240              | Optimize Results Display                                        | Update/Modify Item                | US10                  |
| 240              | Verify Across Pages                                             | Analyze/Evaluate/Verify Data      | US7                   |
| 247              | Locate Negative Reviews for Zoe Products                        | Search/Filter/Sort Data           | US2                   |
| 247              | Retrieve Customer Email                                         | Extract/Retrieve Information      | US6                   |
| 250              | Search for Apple Store in Pittsburgh via OpenStreetMap          | Search/Filter/Sort Data           | US2                   |
| 250              | Retrieve coordinates in DD format                               | Extract/Retrieve Information      | US6                   |
| 254              | Search for the Hospital                                         | Search/Filter/Sort Data           | US2                   |
| 254              | Access Hospital Details                                         | View/Inspect Item Details         | US5                   |
| 254              | Retrieve Phone Number                                           | Extract/Retrieve Information      | US6                   |
| 258              | Navigate to Public Projects via Explore Section                 | Navigate To Page/Section          | US1                   |
| 259              | Navigate to Access Tokens Section                               | Navigate To Page/Section          | US1                   |
| 259              | Retrieve RSS Feed Token                                         | Extract/Retrieve Information      | US6                   |
| 268              | Locate Vinalhaven, ME on OpenStreetMap                          | Navigate To Page/Section          | US1                   |
| 268              | Confirm location and access detailed information                | View/Inspect Item Details         | US5                   |
| 268              | Find Acadia National Park and calculate biking route            | Execute Action/Process            | US4                   |
| 27               | Navigate to Showerthoughts Forum and Find Latest Post           | Navigate To Page/Section          | US1                   |
| 27               | Access the Author's Profile                                     | Navigate To Page/Section          | US1                   |
| 27               | Analyze Comments for Downvote Count                             | Analyze/Evaluate/Verify Data      | US7                   |
| 270              | Navigate to Men's Shoes Category                                | Navigate To Page/Section          | US1                   |
| 270              | Filter Products by Price                                        | Search/Filter/Sort Data           | US2                   |
| 270              | Optimize Product Display                                        | Update/Modify Item                | US10                  |
| 276              | Search for 'switch accessories'                                  | Search/Filter/Sort Data           | US2                   |
| 279              | Initiate Search for Sony Bluetooth Headphones                   | Search/Filter/Sort Data           | US2                   |
| 279              | Organize Product Listings                                       | Search/Filter/Sort Data           | US2                   |
| 279              | Collect Product Data                                            | Extract/Retrieve Information      | US6                   |
| 283              | Perform Initial Search for Xbox Controllers                     | Search/Filter/Sort Data           | US2                   |
| 283              | Refine Search to Target Specific Models                         | Search/Filter/Sort Data           | US2                   |
| 283              | Navigate Through Search Result Pages                            | Navigate Within Data/Results      | US8                   |
| 283              | Inspect Product Details for Release Dates                       | View/Inspect Item Details         | US5                   |
| 285              | Perform Initial Search for 'switch card holder'                 | Search/Filter/Sort Data           | US2                   |
| 285              | Optimize Search Results for Price and Capacity Evaluation       | Analyze/Evaluate/Verify Data      | US7                   |
| 285              | Identify and Validate the Least Expensive Qualifying Product    | Analyze/Evaluate/Verify Data      | US7                   |
| 287              | Locate Pittsburgh on the map                                    | Navigate To Page/Section          | US1                   |
| 287              | Configure route parameters                                      | Configure Parameters/Settings     | US3                   |
| 287              | Calculate and retrieve driving time                             | Execute Action/Process            | US4                   |
| 288              | Navigate to Customer Order Report                               | Navigate To Page/Section          | US1                   |
| 288              | Configure Report Parameters                                     | Configure Parameters/Settings     | US3                   |
| 288              | Generate and Analyze Report                                     | Execute Action/Process            | US4                   |
| 296              | Search and Access the PyTorch-GAN Project                       | Navigate To Page/Section          | US1                   |
| 296              | Clone the Repository Using SSH                                  | Execute Action/Process            | US4                   |
| 305              | Navigate to the Commits Section                                 | Navigate To Page/Section          | US1                   |
| 305              | Filter Commits by Author and Date                               | Search/Filter/Sort Data           | US2                   |
| 305              | Count Filtered Commits                                          | Analyze/Evaluate/Verify Data      | US7                   |
| 313              | Navigate to the Contact Us Page                                 | Navigate To Page/Section          | US1                   |
| 313              | Locate the Customer Service Phone Number                        | Extract/Retrieve Information      | US6                   |
| 321              | Access Order History                                            | Navigate To Page/Section          | US1                   |
| 321              | Locate Canceled 2022 Order                                      | Search/Filter/Sort Data           | US2                   |
| 321              | Review Order Details for Refund Information                     | Analyze/Evaluate/Verify Data      | US7                   |
| 324              | Search for 'chairs'                                             | Search/Filter/Sort Data           | US2                   |
| 324              | Sort results by ascending price                                 | Search/Filter/Sort Data           | US2                   |
| 33               | Locate Hilton Hotel near Pittsburgh Airport                     | Search/Filter/Sort Data           | US2                   |
| 33               | Identify Nearest Supermarket to the Hotel                       | Search/Filter/Sort Data           | US2                   |
| 33               | Calculate Shortest Walking Route                                | Execute Action/Process            | US4                   |
| 333              | Access Order History                                            | Navigate To Page/Section          | US1                   |
| 333              | Identify and Calculate Discounted Orders                        | Analyze/Evaluate/Verify Data      | US7                   |
| 335              | Access Order History via My Account                             | Navigate To Page/Section          | US1                   |
| 335              | Review Order Details                                            | View/Inspect Item Details         | US5                   |
| 335              | Navigate Multi-page Results                                     | Navigate Within Data/Results      | US8                   |
| 341              | Navigate to Issues Section                                      | Navigate To Page/Section          | US1                   |
| 341              | Filter by Feature Request Label                                 | Search/Filter/Sort Data           | US2                   |
| 348              | Navigate to Advanced Reporting & Product Reviews Report         | Navigate To Page/Section          | US1                   |
| 348              | Filter Reviews by May 2023 Date Range                           | Search/Filter/Sort Data           | US2                   |
| 348              | Execute Search & Retrieve Results                               | Execute Action/Process            | US4                   |
| 349              | Navigate to Target Project                                      | Navigate To Page/Section          | US1                   |
| 349              | Access Member Permissions                                       | View/Inspect Item Details         | US5                   |
| 349              | Identify Authorized Users                                       | Analyze/Evaluate/Verify Data      | US7                   |
| 354              | Navigate to Living Room Furniture Category                      | Navigate To Page/Section          | US1                   |
| 354              | Sort Products by Descending Price                               | Search/Filter/Sort Data           | US2                   |
| 357              | Access Merge Requests Section                                   | Navigate To Page/Section          | US1                   |
| 357              | Filter Merge Requests Requiring Review                          | Search/Filter/Sort Data           | US2                   |
| 361              | Access Order History                                            | Navigate To Page/Section          | US1                   |
| 367              | Initiate Directions Between Two Points                          | Configure Parameters/Settings     | US3                   |
| 367              | Locate Target CVS Pharmacy                                      | Search/Filter/Sort Data           | US2                   |
| 367              | Calculate Walking Route                                         | Execute Action/Process            | US4                   |
| 368              | Access Advanced Search Functionality                            | Navigate To Page/Section          | US1                   |
| 368              | Execute Discount-Focused Search                                 | Execute Action/Process            | US4                   |
| 368              | Validate Discounted Products                                    | Analyze/Evaluate/Verify Data      | US7                   |
| 369              | Close Welcome Modal and Search for Carnegie Music Hall          | Search/Filter/Sort Data           | US2                   |
| 369              | Access Description Page on Map                                  | View/Inspect Item Details         | US5                   |
| 369              | Verify External Details (Optional)                              | Analyze/Evaluate/Verify Data      | US7                   |
| 37               | Access Directions Feature                                       | Navigate To Page/Section          | US1                   |
| 37               | Input Initial Route Points                                      | Configure Parameters/Settings     | US3                   |
| 37               | Correct Route Direction                                         | Configure Parameters/Settings     | US3                   |
| 37               | Generate and Review Route                                       | Execute Action/Process            | US4                   |
| 374              | Navigate to Themes Section                                      | Navigate To Page/Section          | US1                   |
| 374              | Select Magento Blank Theme                                      | Update/Modify Item                | US10                  |
| 374              | Review Theme Configuration                                      | View/Inspect Item Details         | US5                   |
| 376              | Navigate to Amazon Echo Dot 3rd Gen Product Page                | Navigate To Page/Section          | US1                   |
| 376              | Access Customer Reviews                                         | Navigate To Page/Section          | US1                   |
| 381              | Search for Hotels Near Carnegie Music Hall                      | Search/Filter/Sort Data           | US2                   |
| 382              | Locate the USCIS Office Near Carnegie Mellon University         | Search/Filter/Sort Data           | US2                   |
| 382              | Find the Nearest Social Security Administration (SSA) Office from USCIS | Search/Filter/Sort Data           | US2                   |
| 382              | Calculate Walking Distance from USCIS to SSA                    | Execute Action/Process            | US4                   |
| 383              | Locate Hyatt Hotel near Pittsburgh Airport                      | Search/Filter/Sort Data           | US2                   |
| 383              | Find supermarkets within 15 minutes drive from the Hyatt        | Search/Filter/Sort Data           | US2                   |
| 384              | Navigate to the EYZUTAK Phone Case Product Page                 | Navigate To Page/Section          | US1                   |
| 384              | Access Customer Reviews Section                                 | Navigate To Page/Section          | US1                   |
| 384              | Navigate Through Review Pages                                   | Navigate Within Data/Results      | US8                   |
| 384              | Identify and Extract Complainant Names                          | Extract/Retrieve Information      | US6                   |
| 386              | Search for the Product                                          | Search/Filter/Sort Data           | US2                   |
| 386              | Access Product Details                                          | View/Inspect Item Details         | US5                   |
| 386              | Retrieve Product Rating                                         | Extract/Retrieve Information      | US6                   |
| 387              | Search for EYZUTAK Phone Cases                                  | Search/Filter/Sort Data           | US2                   |
| 387              | Access Product Details and Reviews                              | View/Inspect Item Details         | US5                   |
| 387              | Identify 4/5-Star Reviewers                                     | Analyze/Evaluate/Verify Data      | US7                   |
| 392              | Navigate to the Project's Merge Requests Section                | Navigate To Page/Section          | US1                   |
| 392              | Locate the Target Merge Request                                 | Search/Filter/Sort Data           | US2                   |
| 392              | Post the Comment                                                | Execute Action/Process            | US4                   |
| 4                | Navigate to Bestsellers Report                                  | Navigate To Page/Section          | US1                   |
| 4                | Configure Report Parameters for January 2023                    | Configure Parameters/Settings     | US3                   |
| 4                | Generate and Review Bestsellers Report                          | Execute Action/Process            | US4                   |
| 404              | Navigate to the Books Forum                                     | Navigate To Page/Section          | US1                   |
| 404              | Sort Posts by Newest                                            | Search/Filter/Sort Data           | US2                   |
| 404              | Upvote the Newest Post                                          | Execute Action/Process            | US4                   |
| 419              | Access User Menu and Open Status Modal                          | Navigate To Page/Section          | US1                   |
| 419              | Input and Save Custom Status                                    | Update/Modify Item                | US10                  |
| 419              | Validate Status Update                                          | Analyze/Evaluate/Verify Data      | US7                   |
| 423              | Navigate to Product Management                                  | Navigate To Page/Section          | US1                   |
| 423              | Search for Hollister Shirts                                     | Search/Filter/Sort Data           | US2                   |
| 423              | Bulk Selection and Status Update                                | Update/Modify Item                | US10                  |
| 426              | Access Wikipedia to Identify the 9/11 Pennsylvania Plane Crash Site | Navigate To Page/Section          | US1                   |
| 426              | Locate Crash Site on OpenStreetMap                              | Navigate To Page/Section          | US1                   |
| 43               | Navigate to the Search Terms Report                             | Navigate To Page/Section          | US1                   |
| 43               | Identify Top 3 Search Terms                                     | Analyze/Evaluate/Verify Data      | US7                   |
| 44               | Access User Profile and Navigation                              | Navigate To Page/Section          | US1                   |
| 44               | Search for Target Project                                       | Search/Filter/Sort Data           | US2                   |
| 44               | Access TODO Project                                             | Navigate To Page/Section          | US1                   |
| 44               | Review Assigned Todos                                           | View/Inspect Item Details         | US5                   |
| 440              | Access Order History to Locate the Canceled Order               | Navigate To Page/Section          | US1                   |
| 440              | Search and Add the Product Manually                             | Execute Action/Process            | US4                   |
| 440              | Adjust Cart and Complete Purchase                               | Execute Action/Process            | US4                   |
| 443              | Access and Edit the index.html File                             | Update/Modify Item                | US10                  |
| 443              | Commit the Changes                                              | Execute Action/Process            | US4                   |
| 448              | Access Profile Settings                                         | Navigate To Page/Section          | US1                   |
| 448              | Update Homepage URL                                             | Update/Modify Item                | US10                  |
| 454              | Navigate to Products Management Section                         | Navigate To Page/Section          | US1                   |
| 454              | Search for Target Product                                       | Search/Filter/Sort Data           | US2                   |
| 454              | Access Product Edit Page                                        | Navigate To Page/Section          | US1                   |
| 454              | Disable Product and Save Changes                                | Update/Modify Item                | US10                  |
| 458              | Modify Product Price                                            | Update/Modify Item                | US10                  |
| 46               | Navigate to the Issues Section                                  | Navigate To Page/Section          | US1                   |
| 46               | Filter and Sort Open Issues                                     | Search/Filter/Sort Data           | US2                   |
| 464              | Navigate to the Antonia Racer Tank Product Edit Page            | Navigate To Page/Section          | US1                   |
| 464              | Extract Positive User Reviews                                   | Extract/Retrieve Information      | US6                   |
| 464              | Integrate Reviews into Product Description                      | Update/Modify Item                | US10                  |
| 466              | Search for the Product                                          | Search/Filter/Sort Data           | US2                   |
| 466              | Add Product to Wish List                                        | Execute Action/Process            | US4                   |
| 471              | Navigate to Order 307 Details                                   | Navigate To Page/Section          | US1                   |
| 471              | Cancel the Order                                                | Execute Action/Process            | US4                   |
| 476              | Initiate Project Creation                                       | Execute Action/Process            | US4                   |
| 476              | Configure Project Details                                       | Configure Parameters/Settings     | US3                   |
| 476              | Finalize Project Creation                                       | Create Item                       | US9                   |
| 48               | Access Order History                                            | Navigate To Page/Section          | US1                   |
| 48               | Paginate Through Orders                                         | Navigate Within Data/Results      | US8                   |
| 48               | Review and Calculate Totals                                     | Analyze/Evaluate/Verify Data      | US7                   |
| 485              | Navigate to the Dotfiles Project                                | Navigate To Page/Section          | US1                   |
| 485              | Access Project Members Section                                  | Navigate To Page/Section          | US1                   |
| 485              | Invite Vinta as a Guest                                         | Execute Action/Process            | US4                   |
| 488              | Navigate to the Home Page Edit Interface                        | Navigate To Page/Section          | US1                   |
| 488              | Modify and Save the Page Title                                  | Update/Modify Item                | US10                  |
| 497              | Navigate to Order #307                                          | Navigate To Page/Section          | US1                   |
| 497              | Update Shipment with Tracking Number                            | Update/Modify Item                | US10                  |
| 505              | Navigate to Products Section                                    | Navigate To Page/Section          | US1                   |
| 505              | Search for Aeno Capri Products                                  | Search/Filter/Sort Data           | US2                   |
| 505              | Update Stock Status to Out of Stock                             | Update/Modify Item                | US10                  |
| 506              | Navigate to Meat Substitutes Category                           | Navigate To Page/Section          | US1                   |
| 506              | Filter Products by Budget                                       | Search/Filter/Sort Data           | US2                   |
| 506              | Select Highest-Rated Product                                    | Execute Action/Process            | US4                   |
| 506              | Proceed to Checkout                                             | Execute Action/Process            | US4                   |
| 506              | Complete Order Placement                                        | Execute Action/Process            | US4                   |
| 509              | Navigate to Men's Shoes Category                                | Navigate To Page/Section          | US1                   |
| 509              | Sort Products by Price                                          | Search/Filter/Sort Data           | US2                   |
| 509              | Browse and Filter Products                                      | Search/Filter/Sort Data           | US2                   |
| 509              | Select Product and Options                                      | Execute Action/Process            | US4                   |
| 509              | Add to Cart and Checkout                                        | Execute Action/Process            | US4                   |
| 514              | Search for 'white desk'                                         | Search/Filter/Sort Data           | US2                   |
| 514              | Add product to wish list                                        | Execute Action/Process            | US4                   |
| 516              | Access Account and Wishlist Management                          | Navigate To Page/Section          | US1                   |
| 516              | Return to Product Page                                          | Navigate To Page/Section          | US1                   |
| 516              | Add Product to Wishlist                                         | Execute Action/Process            | US4                   |
| 521              | Access Account Dashboard                                        | Navigate To Page/Section          | US1                   |
| 521              | Manage Newsletter Subscriptions                                 | Update/Modify Item                | US10                  |
| 524              | Navigate to Most Starred Projects                               | Navigate To Page/Section          | US1                   |
| 524              | Star Top Eight Projects                                         | Execute Action/Process            | US4                   |
| 528              | Access Order Details to Retrieve Order ID                       | View/Inspect Item Details         | US5                   |
| 528              | Navigate to Contact Form                                        | Navigate To Page/Section          | US1                   |
| 528              | Draft Refund Message                                            | Execute Action/Process            | US4                   |
| 534              | Follow Jakub Klinkovský (lahwaacz)                              | Execute Action/Process            | US4                   |
| 534              | Follow Vinta Chen                                               | Execute Action/Process            | US4                   |
| 538              | Navigate to Order #299 Details                                  | Navigate To Page/Section          | US1                   |
| 538              | Edit the Order Address                                          | Update/Modify Item                | US10                  |
| 538              | Save the Updated Address                                        | Update/Modify Item                | US10                  |
| 548              | Navigate to Frankie Sweatshirt Product Page                     | Navigate To Page/Section          | US1                   |
| 548              | Clean Existing Blue Variants                                    | Update/Modify Item                | US10                  |
| 548              | Add Blue Color to Target Sizes                                  | Update/Modify Item                | US10                  |
| 56               | Initialize Mapping Context                                      | Navigate To Page/Section          | US1                   |
| 56               | Locate Carnegie Museum of Art                                   | Navigate To Page/Section          | US1                   |
| 56               | Identify Target Library                                         | Search/Filter/Sort Data           | US2                   |
| 56               | Calculate Walking Route                                         | Execute Action/Process            | US4                   |
| 566              | Create GitLab Repository 'Do it myself' with README             | Create Item                       | US9                   |
| 566              | Collect Top 8 Active DIY Post URLs from Reddit                  | Extract/Retrieve Information      | US6                   |
| 566              | Edit README with DIY Post Links and Commit                      | Update/Modify Item                | US10                  |
| 574              | Navigate to Address Management                                  | Navigate To Page/Section          | US1                   |
| 574              | Edit Existing Address                                           | Update/Modify Item                | US10                  |
| 574              | Update Address Fields                                           | Update/Modify Item                | US10                  |
| 574              | Finalize Changes                                                | Update/Modify Item                | US10                  |
| 577              | Navigate to Project Members Section                             | Navigate To Page/Section          | US1                   |
| 577              | Invite Users as Maintainers                                     | Execute Action/Process            | US4                   |
| 58               | Access the Map Interface                                        | Navigate To Page/Section          | US1                   |
| 58               | Search for Cafes Near Hunt Library                              | Search/Filter/Sort Data           | US2                   |
| 58               | Review and Select Cafes from Results                            | Execute Action/Process            | US4                   |
| 58               | Inspect Specific Cafe Details                                   | View/Inspect Item Details         | US5                   |
| 582              | Navigate to Forum Creation Page                                 | Navigate To Page/Section          | US1                   |
| 582              | Fill Basic Forum Details                                        | Configure Parameters/Settings     | US3                   |
| 582              | Configure Sidebar Content                                       | Configure Parameters/Settings     | US3                   |
| 582              | Submit Forum Creation                                           | Create Item                       | US9                   |
| 593              | Navigate to Milestones Section                                  | Navigate To Page/Section          | US1                   |
| 593              | Initiate New Milestone Creation                                 | Execute Action/Process            | US4                   |
| 593              | Define Milestone Details                                        | Configure Parameters/Settings     | US3                   |
| 593              | Finalize Milestone Creation                                     | Create Item                       | US9                   |
| 599              | Navigate to the Machine Learning Forum                          | Navigate To Page/Section          | US1                   |
| 599              | Locate the Trending Post                                        | Search/Filter/Sort Data           | US2                   |
| 599              | Access the Thread and Subscribe                                 | Execute Action/Process            | US4                   |
| 605              | Navigate to the Consoles Forum                                  | Navigate To Page/Section          | US1                   |
| 605              | Create and Submit a Post in the Consoles Forum                  | Create Item                       | US9                   |
| 612              | Navigate to the r/books Forum                                   | Navigate To Page/Section          | US1                   |
| 612              | Initiate a New Submission                                       | Execute Action/Process            | US4                   |
| 612              | Compose the Post                                                | Configure Parameters/Settings     | US3                   |
| 612              | Submit the Post                                                 | Create Item                       | US9                   |
| 619              | Access the Existing Image Post                                  | Navigate To Page/Section          | US1                   |
| 619              | Initiate a New Submission to the Funny Subreddit                | Execute Action/Process            | US4                   |
| 619              | Fill in Submission Details                                      | Configure Parameters/Settings     | US3                   |
| 619              | Submit the Post                                                 | Create Item                       | US9                   |
| 626              | Navigate to the iPhone Forum's Submission Page                  | Navigate To Page/Section          | US1                   |
| 626              | Create and Submit the Discussion Post                           | Create Item                       | US9                   |
| 641              | Search and Navigate to the Books Subreddit                      | Navigate To Page/Section          | US1                   |
| 641              | Access the Submission Form                                      | Navigate To Page/Section          | US1                   |
| 641              | Compose the Notice                                              | Configure Parameters/Settings     | US3                   |
| 641              | Submit the Post                                                 | Create Item                       | US9                   |
| 645              | Navigate to the Books Subreddit                                 | Navigate To Page/Section          | US1                   |
| 645              | Compose and Submit the Post                                     | Create Item                       | US9                   |
| 65               | Navigate to the Customers Page                                  | Navigate To Page/Section          | US1                   |
| 65               | Sort and Identify the Fifth Customer                            | Search/Filter/Sort Data           | US2                   |
| 652              | Activate the Comment Input Field                                | Execute Action/Process            | US4                   |
| 652              | Input and Validate Comment Content                              | Configure Parameters/Settings     | US3                   |
| 652              | Submit the Comment                                              | Create Item                       | US9                   |
| 668              | Navigate to the Target Project                                  | Navigate To Page/Section          | US1                   |
| 668              | Initiate Merge Request Creation                                 | Execute Action/Process            | US4                   |
| 668              | Configure Source and Target Branches                            | Configure Parameters/Settings     | US3                   |
| 668              | Assign Reviewer                                                 | Configure Parameters/Settings     | US3                   |
| 668              | Submit Merge Request                                            | Create Item                       | US9                   |
| 678              | Navigate to Orders Report                                       | Navigate To Page/Section          | US1                   |
| 678              | Filter by Canceled Status                                       | Search/Filter/Sort Data           | US2                   |
| 678              | Set Date Range                                                  | Configure Parameters/Settings     | US3                   |
| 678              | Generate Report                                                 | Execute Action/Process            | US4                   |
| 682              | Find GitLab Repository Related to ChatGPT                       | Search/Filter/Sort Data           | US2                   |
| 682              | Navigate to Relevant Subreddit                                  | Navigate To Page/Section          | US1                   |
| 682              | Create Reddit Post Linking to the Repository                    | Create Item                       | US9                   |
| 686              | Locate the Angular-Storage Repository on GitLab                 | Navigate To Page/Section          | US1                   |
| 686              | Navigate to the Forum Submission Page                           | Navigate To Page/Section          | US1                   |
| 686              | Prepare Submission Content                                      | Configure Parameters/Settings     | US3                   |
| 686              | Submit the Post                                                 | Create Item                       | US9                   |
| 69               | Navigate to the 'Books' Forum                                   | Navigate To Page/Section          | US1                   |
| 69               | Review Top 10 in 'Books' Forum                                  | View/Inspect Item Details         | US5                   |
| 693              | Navigate to the Contact Form                                    | Navigate To Page/Section          | US1                   |
| 693              | Fill in Personal Information                                    | Configure Parameters/Settings     | US3                   |
| 693              | Compose the Message                                             | Configure Parameters/Settings     | US3                   |
| 693              | Submit the Form                                                 | Execute Action/Process            | US4                   |
| 695              | Navigate to Product Creation Interface                          | Navigate To Page/Section          | US1                   |
| 695              | Configure Product Attributes                                    | Configure Parameters/Settings     | US3                   |
| 695              | Enter Product Details                                           | Configure Parameters/Settings     | US3                   |
| 695              | Assign Categories and Visibility                                | Configure Parameters/Settings     | US3                   |
| 695              | Finalize Product Creation                                       | Create Item                       | US9                   |
| 7                | Locate Pittsburgh International Airport via OpenStreetMap       | Navigate To Page/Section          | US1                   |
| 7                | Verify driving distance from CMU                                | Analyze/Evaluate/Verify Data      | US7                   |
| 7                | Explore alternative airports via Wikipedia                      | Analyze/Evaluate/Verify Data      | US7                   |
| 703              | Navigate to Catalog Price Rules                                 | Navigate To Page/Section          | US1                   |
| 703              | Create New Catalog Price Rule                                   | Execute Action/Process            | US4                   |
| 703              | Configure Rule Details                                          | Configure Parameters/Settings     | US3                   |
| 703              | Finalize and Save Rule                                          | Create Item                       | US9                   |
| 704              | Navigate to the Orders Report Page                              | Navigate To Page/Section          | US1                   |
| 704              | Configure Report Filters                                        | Configure Parameters/Settings     | US3                   |
| 704              | Generate and Review the Report                                  | Execute Action/Process            | US4                   |
| 71               | Search for Chatham University on OpenStreetMap                  | Search/Filter/Sort Data           | US2                   |
| 710              | Navigate to the Shipping Report Section                         | Navigate To Page/Section          | US1                   |
| 710              | Configure and Generate the Shipping Report                      | Execute Action/Process            | US4                   |
| 714              | Navigate to the Gadgets Forum                                   | Navigate To Page/Section          | US1                   |
| 714              | Sort Submissions to Identify the Top Post of All Time           | Search/Filter/Sort Data           | US2                   |
| 714              | Downvote the Top Post                                           | Execute Action/Process            | US4                   |
| 720              | Navigate to CameronKelsey's Submissions Page                    | Navigate To Page/Section          | US1                   |
| 720              | Upvote All Submissions                                          | Execute Action/Process            | US4                   |
| 729              | Navigate to AdamCannon's Submissions                            | Navigate To Page/Section          | US1                   |
| 729              | Dislike All Submissions                                         | Execute Action/Process            | US4                   |
| 733              | Navigate to User Profile to Access Submissions                  | Navigate To Page/Section          | US1                   |
| 733              | Enter Edit Mode for the Target Post                             | Update/Modify Item                | US10                  |
| 733              | Modify Post Body and Submit Changes                             | Update/Modify Item                | US10                  |
| 741              | Identify the Boston Celtics' Home Stadium via Wikipedia         | Navigate To Page/Section          | US1                   |
| 741              | Plan Route via OpenStreetMap                                    | Configure Parameters/Settings     | US3                   |
| 745              | Create the "awesome-llms" Project                               | Create Item                       | US9                   |
| 745              | Add Members to the Project                                      | Execute Action/Process            | US4                   |
| 748              | Create Private Project with Android Template                    | Create Item                       | US9                   |
| 748              | Add Project Members                                             | Execute Action/Process            | US4                   |
| 75               | Set up directions from MIT to Harvard University                | Configure Parameters/Settings     | US3                   |
| 75               | Calculate Harvard University to Boston Logan Airport route      | Execute Action/Process            | US4                   |
| 75               | Document and compare travel times                               | Analyze/Evaluate/Verify Data      | US7                   |
| 760              | Log into Magento Admin Panel                                    | Execute Action/Process            | US4                   |
| 760              | Locate Amanda Kim's Customer Details                            | Search/Filter/Sort Data           | US2                   |
| 760              | Retrieve Amanda's City and State                                | Extract/Retrieve Information      | US6                   |
| 760              | Calculate Route via OpenStreetMap                               | Execute Action/Process            | US4                   |
| 762              | Locate Starting Point (Carnegie Music Hall NYC)                 | Navigate To Page/Section          | US1                   |
| 762              | Initiate Directions Feature                                     | Execute Action/Process            | US4                   |
| 762              | Set Starting Point and Destination                              | Configure Parameters/Settings     | US3                   |
| 762              | Execute Directions with Driving Options                         | Execute Action/Process            | US4                   |
| 768              | Navigate to the Product's Edit Page                             | Navigate To Page/Section          | US1                   |
| 768              | Update Stock Quantity and Save Changes                          | Update/Modify Item                | US10                  |
| 77               | Navigate to the Product Reviews Report                          | Navigate To Page/Section          | US1                   |
| 77               | Filter Reviews by Pending Status                                | Search/Filter/Sort Data           | US2                   |
| 77               | Retrieve the Total Count                                        | Extract/Retrieve Information      | US6                   |
| 771              | Navigate to Pending Reviews Section                             | Navigate To Page/Section          | US1                   |
| 771              | Approve a Specific Review                                       | Update/Modify Item                | US10                  |
| 771              | Repeat for Additional Reviews                                   | Update/Modify Item                | US10                  |
| 773              | Navigate to Pending Reviews Section                             | Navigate To Page/Section          | US1                   |
| 773              | Select Target Negative Reviews                                  | Execute Action/Process            | US4                   |
| 773              | Execute Mass Deletion                                           | Delete Item                       | US11                  |
| 782              | Navigate to Products Section                                    | Navigate To Page/Section          | US1                   |
| 782              | Search and Filter Products                                      | Search/Filter/Sort Data           | US2                   |
| 782              | Edit Configurable Products and Update Variants                  | Update/Modify Item                | US10                  |
| 787              | Navigate to the Master Branch Contributors Section              | Navigate To Page/Section          | US1                   |
| 787              | Identify the Top Contributor by Commit Count                    | Analyze/Evaluate/Verify Data      | US7                   |
| 787              | Access Contributor's Profile for Followers Count                | Analyze/Evaluate/Verify Data      | US7                   |
| 791              | Navigate to the gimmiethat.space Repository                     | Navigate To Page/Section          | US1                   |
| 791              | Create the 'car' Folder and 'urls.txt' File                     | Create Item                       | US9                   |
| 791              | Collect Recent Car Post URLs from Forums                        | Extract/Retrieve Information      | US6                   |
| 791              | Input URLs and Commit the File                                  | Update/Modify Item                | US10                  |
| 798              | Access Address Editing Interface                                | Navigate To Page/Section          | US1                   |
| 798              | Update Address Details                                          | Update/Modify Item                | US10                  |
| 809              | Navigate to the a11yproject.com Project                         | Navigate To Page/Section          | US1                   |
| 809              | Initiate New Issue Creation                                     | Execute Action/Process            | US4                   |
| 809              | Configure Issue Details                                         | Configure Parameters/Settings     | US3                   |
| 809              | Submit the Issue                                                | Create Item                       | US9                   |
| 811              | Navigate to the 404 Issue in a11yproject.com                    | Navigate To Page/Section          | US1                   |
| 811              | Authenticate to Modify the Issue                                | Execute Action/Process            | US4                   |
| 811              | Assign the Issue to Self                                        | Update/Modify Item                | US10                  |
| 82               | Set Massachusetts Institute of Technology (MIT) as Starting Point | Configure Parameters/Settings     | US3                   |
| 82               | Generate Walking Route to Harvard University                    | Execute Action/Process            | US4                   |
| 82               | Calculate Driving Route to Boston Logan International Airport   | Execute Action/Process            | US4                   |
| 88               | Access Directions Interface                                     | Navigate To Page/Section          | US1                   |
| 88               | Set Starting Location                                           | Configure Parameters/Settings     | US3                   |
| 88               | Set Destination Location                                        | Configure Parameters/Settings     | US3                   |
| 93               | Close the Welcome Modal and Access Map Interface                | Navigate To Page/Section          | US1                   |
| 93               | Search for New Hampshire and Center the Map                     | Search/Filter/Sort Data           | US2                   |
| 95               | Navigate to the Orders Page                                     | Navigate To Page/Section          | US1                   |
| 95               | Access Order 000000002 Details                                  | Navigate To Page/Section          | US1                   |
| 95               | Retrieve Grand Total Value                                      | Extract/Retrieve Information      | US6                   |
| 96               | Access Order History and Locate Latest Order                    | Navigate To Page/Section          | US1                   |
| 96               | Review Order Status and Details                                 | View/Inspect Item Details         | US5                   |
| 97               | Access Directions Feature on OpenStreetMap                      | Navigate To Page/Section          | US1                   |
| 97               | Specify Starting Point (Carnegie Mellon University)             | Configure Parameters/Settings     | US3                   |
| 97               | Specify Destination (Top CS School in Massachusetts)            | Configure Parameters/Settings     | US3                   |
| 97               | Calculate and Display Distance                                  | Execute Action/Process            | US4                   |